@@ -1,5 +1,5 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/calctool.c,v 1.65 2004/01/07 15:43:15 richb Exp $
+/*  $Header: /cvs/gnome/gcalctool/gcalctool/calctool.c,v 1.66 2004/01/26 18:59:19 richb Exp $
  *
  *  Copyright (c) 1987-2003 Sun Microsystems, Inc. All Rights Reserved.
  *           
@@ -1049,7 +1049,7 @@ do_calctool(int argc, char **argv)
         }
     }
 
-    SPRINTF(title, "%s [%s]", v->tool_label, _(mstrs[(int) v->modetype]));
+    SPRINTF(title, "%s- %s", v->tool_label, _(mstrs[(int) v->modetype]));
     set_title(FCP_KEY, title);
 
     show_display(v->MPdisp_val);     /* Output in correct display mode. */
