@@ -1,5 +1,5 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/calctool.h,v 1.45 2003/12/23 14:21:12 richb Exp $
+/*  $Header: /cvs/gnome/gcalctool/gcalctool/calctool.h,v 1.46 2004/01/22 17:50:57 richb Exp $
  *
  *  Copyright (c) 1987-2003 Sun Microsystems, Inc. All Rights Reserved.
  *           
@@ -331,6 +331,7 @@ int get_menu_entry(enum menu_type, int);
 int key_equal(struct button *, struct button);
 int main(int, char **);
 
+void adjust_radix(char *);
 void add_tsep();
 void beep();
 void clear_display(int);
@@ -375,7 +376,7 @@ void make_frames();
 void make_menus();
 void make_reg(int, char *);
 void make_registers();
-void MPstr_to_num(char *, enum base_type, int *);
+void MPstr_to_num(char *, enum base_type, gboolean, int *);
 void paren_disp(char);
 void process_item(struct button *);
 void process_stack(int, int, int);
@@ -386,6 +387,7 @@ void put_resource(enum res_type, char *);
 void read_cfdefs();
 void read_resources();
 void read_str(char **, char *);
+void remove_tsep(char *);
 void save_pending_values(struct button *);
 void save_resources();
 void set_accuracy_toggle(int);
