@@ -1,5 +1,5 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/functions.c,v 1.25 2003/07/08 15:17:08 richb Exp $
+/*  $Header: /cvs/gnome/gcalctool/gcalctool/functions.c,v 1.35 2004/01/26 18:59:19 richb Exp $
  *
  *  Copyright (c) 1987-2003 Sun Microsystems, Inc. All Rights Reserved.
  *           
@@ -305,7 +305,7 @@ do_calc()      /* Perform arithmetic calculation and display result. */
 
     } else if (IS_KEY(v->cur_op, KEY_PER.value[0])) {     /* % */
         mpmul(v->MPresult, v->MPdisp_val, v->MPresult);
-        MPstr_to_num("0.01", DEC, MP1);
+        MPstr_to_num("0.01", DEC, FALSE, MP1);
         mpmul(v->MPresult, MP1, v->MPresult);
 
     } else if (IS_KEY(v->cur_op, KEY_YTOX.value[0])) {    /* y^x */
@@ -386,8 +386,24 @@ do_constant()
 void
 do_delete()     /* Remove the last numeric character typed. */
 {
-    if (strlen(v->display) > 0) {
-        v->display[strlen(v->display)-1] = '\0';
+    size_t len;
+
+    len = strlen(v->display);
+    if (len > 0) {
+        size_t l2;
+
+	l2 = strlen(v->radix);
+        if (len >= l2 && memcmp(v->display + len - l2, v->radix, l2) == 0) {
+	    v->display[len-l2] = '\0';
+	} else {
+	    l2 = strlen(v->tsep);
+	    if (len >= l2
+		&& memcmp(v->display + len - l2, v->tsep, l2) == 0) {
+	        v->display[len-l2] = '\0';
+	    } else {
+	        v->display[len-1] = '\0';
+	    }
+	}
     }
 
 /*  If we were entering a scientific number, and we have backspaced over
@@ -401,12 +417,18 @@ do_delete()     /* Remove the last numeric character typed. */
 
 /* If we've backspaced over the numeric point, clear the pointed flag. */
 
-    if (v->pointed && !(strchr(v->display, '.'))) {
+    if (v->pointed && !(strstr(v->display, v->radix))) {
         v->pointed = 0;
     }
 
     set_display(v->display);
-    MPstr_to_num(v->display, v->base, v->MPdisp_val);
+    MPstr_to_num(v->display, v->base, FALSE, v->MPdisp_val);
+
+    if (v->dtype == FIX) {
+        STRCPY(v->fnum, v->display);
+        add_tsep();
+        set_display(v->fnum);
+    }
 }
 
 
@@ -425,12 +447,15 @@ do_exchange()         /* Exchange display with memory register. */
 void
 do_expno()           /* Get exponential number. */
 {
-    v->pointed = (strchr(v->display, '.') != NULL);
+    v->pointed = (strstr(v->display, v->radix) != NULL);
     if (!v->new_input) {
         STRCPY(v->display, "1.0 +");
         v->new_input = v->pointed = 1;
     } else if (!v->pointed) {
-        STRNCAT(v->display, ". +", 3);
+        char str[4];
+
+        SPRINTF(str, "%s +", v->radix);
+        STRNCAT(v->display, str, 3);
         v->pointed = 1;
     } else if (!v->key_exp) {
         STRNCAT(v->display, " +", 2);
@@ -439,7 +464,7 @@ do_expno()           /* Get exponential number. */
     v->key_exp = 1;
     v->exp_posn = strchr(v->display, '+');
     set_display(v->display);
-    MPstr_to_num(v->display, v->base, v->MPdisp_val);
+    MPstr_to_num(v->display, v->base, FALSE, v->MPdisp_val);
 }
 
 
@@ -574,7 +599,7 @@ do_immed()
                 *v->exp_posn = '+';
             }
             set_display(v->display);
-            MPstr_to_num(v->display, v->base, v->MPdisp_val);
+            MPstr_to_num(v->display, v->base, FALSE, v->MPdisp_val);
             v->key_exp = 0;
         } else {
             mpneg(v->MPdisp_val, v->MPdisp_val);
@@ -598,10 +623,11 @@ do_mode()                   /* Set special calculator mode. */
 {
     char title[MAXLINE];
 
-    SPRINTF(title, "%s [%s]", v->tool_label, _(mstrs[(int) v->modetype]));
+    SPRINTF(title, "%s- %s", v->tool_label, _(mstrs[(int) v->modetype]));
     set_title(FCP_KEY, title);
     put_resource(R_MODE, Rmstr[(int) v->modetype]);
     set_mode(v->modetype);
+    do_clear();
 }
 
 
@@ -621,9 +647,8 @@ do_number()
     nextchar = v->current->value[0];
     n = v->current->value[0] - '0';
     if (v->base == HEX && 
-        v->current->value[0] >= 'a' && v->current->value[0] <= 'f') {
-        nextchar -= 32;             /* Convert to uppercase hex digit. */
-        n = v->current->value[0] - 'a' + 10;
+        v->current->value[0] >= 'A' && v->current->value[0] <= 'F') {
+        n = v->current->value[0] - 'A' + 10;
     }
     if (n > maxvals[(int) v->base]) {
         beep();
@@ -641,7 +666,7 @@ do_number()
         }
     }
     set_display(v->display);
-    MPstr_to_num(v->display, v->base, v->MPdisp_val);
+    MPstr_to_num(v->display, v->base, FALSE, v->MPdisp_val);
     v->new_input = 1;
 }
 
@@ -689,7 +714,7 @@ do_paren()
         }
         v->noparens--;
         if (!v->noparens) {
-            paren_disp(v->current->value[0]);
+            paren_disp(v->current->func_char);
             ptr = v->display;
             while (*ptr != '(') {
                 ptr++;
@@ -700,7 +725,7 @@ do_paren()
             return;
         }
     }
-    paren_disp(v->current->value[0]);
+    paren_disp(v->current->func_char);
 }
 
 
@@ -773,15 +798,15 @@ do_point()                   /* Handle numeric point. */
 {
     if (!v->pointed) {
         if (v->toclear) {
-            STRCPY(v->display, ".");
+            STRCPY(v->display, v->radix);
             v->toclear = 0;
         } else {
-            STRNCAT(v->display, ".", 1);
+            STRCAT(v->display, v->radix);
         }
         v->pointed = 1;
     }
     set_display(v->display);
-    MPstr_to_num(v->display, v->base, v->MPdisp_val);
+    MPstr_to_num(v->display, v->base, FALSE, v->MPdisp_val);
 }
 
 
@@ -823,7 +848,7 @@ do_shift()     /* Perform bitwise shift on display value. */
     for (i = 0; i <= 15; i++) {
         if (v->current->value[0] == get_menu_entry(mtype, i)) {
             shift = char_val(v->current->value[0]);
-            MPstr_to_num(v->display, v->base, MPtemp);
+            MPstr_to_num(v->display, v->base, FALSE, MPtemp);
             mpcmd(MPtemp, &dval);
             temp = ibool(dval);
 
@@ -1159,7 +1184,7 @@ mpatanh(int *MPx, int *MPretval)
         mpsub(MP1, MPx, MP3);
         mpdiv(MP2, MP3, MP3);
         mpln(MP3, MP3);
-        MPstr_to_num("0.5", DEC, MP1);
+        MPstr_to_num("0.5", DEC, FALSE, MP1);
         mpmul(MP1, MP3, MPretval);
     }
 }
