@@ -1,5 +1,5 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/gtk.c,v 1.107 2003/12/03 22:20:03 richb Exp $
+/*  $Header: /cvs/gnome/gcalctool/gcalctool/gtk.c,v 1.110 2004/01/26 17:30:14 richb Exp $
  *
  *  Copyright (c) 1987-2003 Sun Microsystems, Inc. All Rights Reserved.
  *           
@@ -86,9 +86,9 @@ typedef struct Xobject {               /* Gtk+/Xlib graphics object. */
     GtkWidget *fin_buttons[FROWS * FCOLS];
     GtkWidget *sci_buttons[SROWS * SCOLS];
 
-    GtkWidget *bas_frame;
-    GtkWidget *fin_frame;
-    GtkWidget *sci_frame;
+    GtkWidget *bas_panel;
+    GtkWidget *fin_panel;
+    GtkWidget *sci_panel;
 
     Display *dpy;
 
@@ -117,7 +117,7 @@ typedef struct {
 static GtkWidget *create_menu(enum menu_type, struct button *);
 static GtkWidget *create_mode_panel(GtkWidget *);
 static GtkWidget *make_menu_button(gchar *, int);
-static GtkWidget *make_but_frame(GtkWidget *, GtkWidget **,
+static GtkWidget *make_but_panel(GtkWidget *, GtkWidget **,
                                  struct button *, int, int, char *);
 
 static char *make_hostname(Display *);
@@ -170,7 +170,7 @@ static GtkItemFactoryEntry main_menu[] = {
     { N_("/Edit/_Copy"),           NULL, mb_proc, M_COPY,  "<StockItem>", GTK_STOCK_COPY },
     { N_("/Edit/_Paste"),          NULL, mb_proc, M_PASTE, "<StockItem>", GTK_STOCK_PASTE },
     { N_("/Edit/sep1"),            NULL, NULL,    0,       "<Separator>" },
-    { N_("/Edit/_Insert ASCII Value..."), "<control>I", mb_proc, M_ASCII, "<StockItem>", GTK_STOCK_CONVERT },
+    { N_("/Edit/_Insert ASCII Value..."), "<control>I", mb_proc, M_ASCII, NULL },
 
     { N_("/_View"),                NULL, NULL,    0,       "<Branch>" },
     { N_("/View/_Basic Mode"),     "<control>B", mb_proc, M_BASIC, "<RadioItem>" },
@@ -553,7 +553,7 @@ cfframe_response_cb(GtkDialog *dialog, gint id, gpointer data)
            item = g_array_index(entries, CF_Item, i);
 
            if (mtype == M_CON) {
-                MPstr_to_num(item.value, DEC, v->MPcon_vals[i]);
+                MPstr_to_num(item.value, DEC, FALSE, v->MPcon_vals[i]);
                 STRCPY(v->con_names[i], item.description);
                 put_constant(i, item.value, item.description);
             } else {
@@ -622,8 +622,7 @@ create_aframe()  /* Create auxiliary frame for ASC key. */
     gtk_widget_show(cancel_button);
     gtk_box_pack_start(GTK_BOX(button_hbox), cancel_button, FALSE, FALSE, 0);
 
-    insert_button = button_new_with_stock_image(_("_Insert"), 
-                                                GTK_STOCK_CONVERT);
+    insert_button = gtk_button_new_with_mnemonic(_("_Insert"));
     g_return_if_fail(insert_button != NULL);
     gtk_widget_ref(insert_button);
     gtk_widget_show(insert_button);
@@ -861,18 +860,21 @@ create_kframe()
     gtk_widget_realize(X->kframe);
     gtk_window_set_title(GTK_WINDOW(X->kframe), _(v->tool_label));
 
-    X->fin_frame = make_but_frame(X->kvbox, X->fin_buttons,
+    X->fin_panel = make_but_panel(X->kvbox, X->fin_buttons,
                                   f_buttons, FROWS, FCOLS, "fin");
-    X->mode_panel = create_mode_panel(X->kvbox);
-    X->sci_frame = make_but_frame(X->kvbox, X->sci_buttons,
-                                  s_buttons, SROWS, SCOLS, "sci");
-    gtk_widget_show(X->fin_frame);
-    gtk_widget_show(X->mode_panel);
-    gtk_widget_show(X->sci_frame);
 
-    X->bas_frame = make_but_frame(X->kvbox, X->bas_buttons,
+    X->mode_panel = create_mode_panel(X->kvbox);
+
+    X->sci_panel = make_but_panel(X->kvbox, X->sci_buttons,
+                                  s_buttons, SROWS, SCOLS, "sci");
+
+    gtk_widget_show(X->fin_panel);
+    gtk_widget_show(X->mode_panel);
+    gtk_widget_show(X->sci_panel);
+
+    X->bas_panel = make_but_panel(X->kvbox, X->bas_buttons,
                                   &b_buttons[0], BROWS, BCOLS, "bas");
-    gtk_widget_show(X->bas_frame);
+    gtk_widget_show(X->bas_panel);
     gtk_window_add_accel_group(GTK_WINDOW(X->kframe), X->kbd_accel);
     grey_buttons(v->base);
     gtk_window_set_icon(GTK_WINDOW(X->kframe), X->icon);
@@ -921,21 +923,17 @@ create_mode_panel(GtkWidget *main_vbox)
     int i;
     AtkObject *access_object;
     GtkWidget *base_hbox, *disp_hbox, *trig_hbox;
-    GtkWidget *row1_hbox, *row2_hbox, *frame, *vbox;
+    GtkWidget *row1_hbox, *row2_hbox, *vbox;
     GSList *base_gr = NULL;
     GSList *disp_gr = NULL;
     GSList *trig_gr = NULL;
 
-    frame = gtk_frame_new(NULL);
-    gtk_widget_show(frame);
-    gtk_container_set_border_width(GTK_CONTAINER(frame), 2);
-    gtk_box_pack_start(GTK_BOX(main_vbox), frame, FALSE, TRUE, 0);
-
     row1_hbox = gtk_hbox_new(FALSE, 0);
     row2_hbox = gtk_hbox_new(FALSE, 0);
 
     vbox = gtk_vbox_new(FALSE, 0);
     gtk_widget_ref(vbox);
+    gtk_container_set_border_width(GTK_CONTAINER(vbox), 6);
 
 /* Make Trig. type radio button widgets. */
  
@@ -1020,9 +1018,9 @@ create_mode_panel(GtkWidget *main_vbox)
 
     gtk_box_pack_start(GTK_BOX(vbox), row1_hbox, FALSE, FALSE, 0);
     gtk_box_pack_start(GTK_BOX(vbox), row2_hbox, FALSE, FALSE, 0);
-    gtk_container_add(GTK_CONTAINER(frame), vbox);
+    gtk_box_pack_start(GTK_BOX(main_vbox), vbox, FALSE, TRUE, 0);
 
-    return(frame);
+    return(vbox);
 }
 
 
@@ -1170,7 +1168,7 @@ get_constant(int n)
         return;
     }   
 
-    MPstr_to_num(vline, DEC, v->MPcon_vals[n]);
+    MPstr_to_num(vline, DEC, TRUE, v->MPcon_vals[n]);
     STRCPY(v->con_names[n], nline);
 }
 
@@ -1458,22 +1456,21 @@ set_accessible_name(GtkWidget *widget, struct button button)
 
 
 static GtkWidget *
-make_but_frame(GtkWidget *vbox, GtkWidget **Gtk_buttons,
+make_but_panel(GtkWidget *vbox, GtkWidget **Gtk_buttons,
                struct button buttons[], int rows, int cols, char *tag)
 {
     char *label, name[MAXLINE];
     int i, j, n;
-    GtkWidget *frame, *l;
+    GtkWidget *l;
     GtkWidget *table = gtk_table_new(rows, cols, TRUE);
 
-    frame = gtk_frame_new(NULL);
-    gtk_widget_show(frame);
-    gtk_box_pack_start(GTK_BOX(vbox), frame, TRUE, TRUE, 0);
+    gtk_table_set_row_spacings(GTK_TABLE(table), 6);
+    gtk_table_set_col_spacings(GTK_TABLE(table), 6);
+    gtk_container_set_border_width(GTK_CONTAINER(table), 6);
 
     gtk_widget_ref(table);
     gtk_widget_show(table);
-    gtk_container_set_border_width(GTK_CONTAINER(frame), 2);
-    gtk_container_add(GTK_CONTAINER(frame), table);
+    gtk_box_pack_start(GTK_BOX(vbox), table, TRUE, TRUE, 0);
 
     for (i = 0; i < cols; i++) {
         for (j = 0; j < rows; j++) {
@@ -1510,11 +1507,11 @@ make_but_frame(GtkWidget *vbox, GtkWidget **Gtk_buttons,
                      i, i+1, j, j+1,
                      (GtkAttachOptions) (GTK_EXPAND | GTK_FILL | GTK_SHRINK),
                      (GtkAttachOptions) (GTK_EXPAND | GTK_FILL | GTK_SHRINK),
-                     4, 4);
+                     0, 0);
         }
     }
 
-    return(frame);
+    return(table);
 }
 
 
@@ -1765,9 +1762,17 @@ static void
 put_constant(int n, char *con_value, char *con_name)
 {
     char key[MAXLINE];
+    char *cstr = g_strdup(con_value);
 
+/* Constants are written out with no thousands seaparator and with a radix
+ * character of ".".
+ */
+
+    remove_tsep(cstr);
+    adjust_radix(cstr);
     SPRINTF(key, "/apps/%s/constant%1dvalue", v->appname, n);
-    gconf_client_set_string(X->client, key, con_value, NULL);
+    gconf_client_set_string(X->client, key, cstr, NULL);
+    g_free(cstr);
 
     SPRINTF(key, "/apps/%s/constant%1dname", v->appname, n);
     gconf_client_set_string(X->client, key, con_name, NULL);
@@ -1955,21 +1960,21 @@ set_mode(enum mode_type mode)
 
     switch (mode) {
         case BASIC:
-            gtk_widget_hide(X->fin_frame);
+            gtk_widget_hide(X->fin_panel);
             gtk_widget_hide(X->mode_panel);
-            gtk_widget_hide(X->sci_frame);
+            gtk_widget_hide(X->sci_panel);
             break;
 
         case FINANCIAL:
-            gtk_widget_show(X->fin_frame);
+            gtk_widget_show(X->fin_panel);
             gtk_widget_hide(X->mode_panel);
-            gtk_widget_hide(X->sci_frame);
+            gtk_widget_hide(X->sci_panel);
             break;
 
         case SCIENTIFIC:
-            gtk_widget_hide(X->fin_frame);
+            gtk_widget_hide(X->fin_panel);
             gtk_widget_show_all(X->mode_panel);
-            gtk_widget_show(X->sci_frame);
+            gtk_widget_show(X->sci_panel);
             break;
     }
 
@@ -1980,8 +1985,8 @@ set_mode(enum mode_type mode)
     gtk_widget_size_request(X->display_item, r);
     w = MAX(w, r->width);
     h += r->height;
-    if (GTK_WIDGET_VISIBLE(X->fin_frame)) {
-        gtk_widget_size_request(X->fin_frame, r);
+    if (GTK_WIDGET_VISIBLE(X->fin_panel)) {
+        gtk_widget_size_request(X->fin_panel, r);
         w = MAX(w, r->width);
         h += r->height;
     }
@@ -1990,8 +1995,8 @@ set_mode(enum mode_type mode)
         w = MAX(w, r->width);
         h += r->height;
     }
-    if (GTK_WIDGET_VISIBLE(X->sci_frame)) {
-        gtk_widget_size_request(X->sci_frame, r);
+    if (GTK_WIDGET_VISIBLE(X->sci_panel)) {
+        gtk_widget_size_request(X->sci_panel, r);
         w = MAX(w, r->width);
     	h += r->height;
     }
